@@ -36,7 +36,23 @@ pub enum StakingInstruction {
     ///   2. `[]` Stake account owner.
     ///   3. `[]` Rent sysvar.
     CreateStakeAccount,
+    /// Deposit to a stake account.
+    ///
+    /// Accounts expected by this instruction:
+    ///   0. `[signer]` authority.
+    ///   1. `[writable]` Stake account.
+    ///   2. `[writable]` Staking pool.
+    ///   3. `[]` Clock sysvar.
+    Deposit(u64),
 
+    /// Withdrawn to a stake account.
+    ///
+    /// Accounts expected by this instruction:
+    ///   0. `[signer]` authority.
+    ///   1. `[writable]` Stake account.
+    ///   2. `[writable]` Staking pool.
+    ///   3. `[]` Clock sysvar.
+    Withdraw(u64),
     /// Claim all unclaimed Reward from a stake account
     ///
     /// Accounts expected by this instruction:
@@ -77,6 +93,14 @@ impl StakingInstruction {
                     ))
                 }
                 1 => Ok((CreateStakeAccount, rest)),
+                2 => {
+                    let (amount, rest) = Self::unpack_u64(rest)?;
+                    Ok((Deposit(amount), rest))
+                }
+                3 => {
+                    let (amount, rest) = Self::unpack_u64(rest)?;
+                    Ok((Withdraw(amount), rest))
+                }
                 4 => Ok((ClaimReward, rest)),
                 _ => {
                     msg!("Instruction cannot be unpacked");
@@ -149,6 +173,14 @@ impl StakingInstruction {
             Self::CreateStakeAccount => {
                 buf.push(1);
             }
+            Self::Deposit(amount) => {
+                buf.push(2);
+                buf.extend_from_slice(&amount.to_le_bytes());
+            }
+            Self::Withdraw(amount) => {
+                buf.push(3);
+                buf.extend_from_slice(&amount.to_le_bytes());
+            }
             Self::ClaimReward => {
                 buf.push(4);
             }
